==> touhoulittlemaid-fabric-1.20.1-0.1.0-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/EntityPowerPointRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.item.EntityPowerPoint;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_897;
import org.joml.Matrix3f;
import org.joml.Matrix4f;

public class EntityPowerPointRenderer extends class_897<EntityPowerPoint> {
    private static final class_2960 POWER_POINT_TEXTURES = new class_2960(TouhouLittleMaid.MOD_ID, "textures/entity/power_point.png");
    private static final class_1921 RENDER_TYPE = class_1921.method_29379(POWER_POINT_TEXTURES);

    public EntityPowerPointRenderer(class_5617.class_5618 renderManager) {
        super(renderManager);
    }

    private static void vertex(class_4588 bufferIn, Matrix4f pose, Matrix3f normal, double x, double y, double texU, double texV, int packedLight) {
        bufferIn.method_22918(pose, (float) x, (float) y, 0.0F).method_1336(255, 255, 255, 255).method_22913((float) texU, (float) texV).method_22922(class_4608.field_21444).method_22916(packedLight).method_23763(normal, 0.0F, 1.0F, 0.0F).method_1344();
    }

    @Override
    public void render(EntityPowerPoint entity, float entityYaw, float partialTicks, class_4587 poseStack, class_4597 bufferIn, int packedLightIn) {
        int texIndex = entity.getIcon();
        int remainder = texIndex % 4;
        int quotient = texIndex / 4;
        double texPos1 = remainder * 16 / 64.0;
        double texPos2 = (remainder * 16 + 16) / 64.0;
        double texPos3 = quotient * 16 / 64.0;
        double texPos4 = (quotient * 16 + 16) / 64.0;

        poseStack.method_22903();
        poseStack.method_22904(0, 0.1, 0);
        poseStack.method_22907(this.field_4676.method_24197());
        poseStack.method_22905(0.3F, 0.3F, 0.3F);

        class_4588 buffer = bufferIn.getBuffer(RENDER_TYPE);
        class_4587.class_4665 poseStackLast = poseStack.method_23760();
        Matrix4f pose = poseStackLast.method_23761();
        Matrix3f normal = poseStackLast.method_23762();

        vertex(buffer, pose, normal, -1, -0.25, texPos1, texPos4, packedLightIn);
        vertex(buffer, pose, normal, 1, -0.25, texPos2, texPos4, packedLightIn);
        vertex(buffer, pose, normal, 1, 1.75, texPos2, texPos3, packedLightIn);
        vertex(buffer, pose, normal, -1, 1.75, texPos1, texPos3, packedLightIn);
        poseStack.method_22909();
    }

    @Override
    public class_2960 getTextureLocation(EntityPowerPoint entity) {
        return POWER_POINT_TEXTURES;
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.1.7.2-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/EntityPowerPointRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.item.EntityPowerPoint;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_7833;
import net.minecraft.class_897;
import org.joml.Matrix3f;
import org.joml.Matrix4f;

public class EntityPowerPointRenderer extends class_897<EntityPowerPoint> {
    private static final class_2960 POWER_POINT_TEXTURES = new class_2960(TouhouLittleMaid.MOD_ID, "textures/entity/power_point.png");
    private static final class_1921 RENDER_TYPE = class_1921.method_29379(POWER_POINT_TEXTURES);

    public EntityPowerPointRenderer(class_5617.class_5618 renderManager) {
        super(renderManager);
    }

    private static void vertex(class_4588 bufferIn, Matrix4f pose, Matrix3f normal, double x, double y, double texU, double texV, int packedLight) {
        bufferIn.method_22918(pose, (float) x, (float) y, 0.0F).method_1336(255, 255, 255, 255).method_22913((float) texU, (float) texV).method_22922(class_4608.field_21444).method_22916(packedLight).method_23763(normal, 0.0F, 1.0F, 0.0F).method_1344();
    }

    @Override
    public void render(EntityPowerPoint entity, float entityYaw, float partialTicks, class_4587 poseStack, class_4597 bufferIn, int packedLightIn) {
        int texIndex = entity.getIcon();
        int remainder = texIndex % 4;
        int quotient = texIndex / 4;
        double texPos1 = remainder * 16 / 64.0;
        double texPos2 = (remainder * 16 + 16) / 64.0;
        double texPos3 = quotient * 16 / 64.0;
        double texPos4 = (quotient * 16 + 16) / 64.0;

        poseStack.method_22903();
        poseStack.method_22904(0, 0.1, 0);
        poseStack.method_22907(this.field_4676.method_24197());
        poseStack.method_22907(class_7833.field_40716.rotationDegrees(180.0F));
        poseStack.method_22905(0.3F, 0.3F, 0.3F);

        class_4588 buffer = bufferIn.getBuffer(RENDER_TYPE);
        class_4587.class_4665 poseStackLast = poseStack.method_23760();
        Matrix4f pose = poseStackLast.method_23761();
        Matrix3f normal = poseStackLast.method_23762();

        vertex(buffer, pose, normal, -1, -0.25, texPos1, texPos4, packedLightIn);
        vertex(buffer, pose, normal, 1, -0.25, texPos2, texPos4, packedLightIn);
        vertex(buffer, pose, normal, 1, 1.75, texPos2, texPos3, packedLightIn);
        vertex(buffer, pose, normal, -1, 1.75, texPos1, texPos3, packedLightIn);
        poseStack.method_22909();
    }

    @Override
    public class_2960 getTextureLocation(EntityPowerPoint entity) {
        return POWER_POINT_TEXTURES;
    }
}
